
.. py:currentmodule:: pythreejs

SphereBufferGeometry
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: SphereBufferGeometry(radius=1, widthSegments=8, heightSegments=6, phiStart=0, phiLength=6.283185307179586, thetaStart=0, thetaLength=3.141592653589793, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.BaseBufferGeometry`.

    Three.js docs: https://threejs.org/docs/#api/geometries/SphereGeometry


    .. py:attribute:: radius

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

    .. py:attribute:: widthSegments

        .. sourcecode:: python

            CInt(8, allow_none=False).tag(sync=True)

    .. py:attribute:: heightSegments

        .. sourcecode:: python

            CInt(6, allow_none=False).tag(sync=True)

    .. py:attribute:: phiStart

        .. sourcecode:: python

            CFloat(0, allow_none=False).tag(sync=True)

    .. py:attribute:: phiLength

        .. sourcecode:: python

            CFloat(6.283185307179586, allow_none=False).tag(sync=True)

    .. py:attribute:: thetaStart

        .. sourcecode:: python

            CFloat(0, allow_none=False).tag(sync=True)

    .. py:attribute:: thetaLength

        .. sourcecode:: python

            CFloat(3.141592653589793, allow_none=False).tag(sync=True)

